"ecolors" gives you many optionas and colors to color your print function in python!
>>>ecolors.red
ecolors.purple
ecolors.blue
ecolors.red
ecolors.cyan
ecolors.green
ecolors.yellow
ecolors.bold
ecolors.underline
ecolors.deafult
